# `libdlr`: Imaginary time calculations using the Discrete Lehmann Representation (DLR)

Authors: [Jason Kaye](https://github.com/jasonkaye) and [Hugo UR Strand](https://github.com/HugoStrand) (2021)

`libdlr` is a library providing Fortran subroutines to build and work with the
discrete Lehmann representation for single particle imaginary time Green's functions,
as well as the stand-alone Python module `pydlr` implementing the same functionality.

For more information see the [documentation](https://libdlr.readthedocs.io).

## Citation

If this library helps you to create software or publications, please let
us know, and cite

- our repository https://github.com/jasonkaye/libdlr, and 
- ["Discrete Lehmann representation of imaginary time Green's functions", Jason Kaye, Kun Chen, and Olivier Parcollet, arXiv:2107.13094](https://arxiv.org/abs/2107.13094)

## Contact

Please email jkaye@flatironinstitute.org with any and all questions.

## License

`libdlr` is licensed under the Apache License, Version 2.0, for more information see the `LICENSE` file.